@@ -24,16 +24,15 @@ from oslo_log import log as logging
 from oslo_utils import strutils
 from oslo_utils import timeutils
 import requests
-import six
-from six.moves import urllib
+import urllib
 
 from senlin.common import consts
 from senlin.common import exception
 from senlin.common.i18n import _
 from senlin.objects import service as service_obj
 
-cfg.CONF.import_opt('max_response_size', 'senlin.common.config')
-cfg.CONF.import_opt('periodic_interval', 'senlin.common.config')
+cfg.CONF.import_opt('max_response_size', 'senlin.conf')
+cfg.CONF.import_opt('periodic_interval', 'senlin.conf')
 
 LOG = logging.getLogger(__name__)
 _ISO8601_TIME_FORMAT = '%Y-%m-%dT%H:%M:%S'
@@ -122,10 +121,7 @@ def url_fetch(url, timeout=1, allowed_schemes=('http', 'https'), verify=True):
         reader = resp.iter_content(chunk_size=1000)
         result = ""
         for chunk in reader:
-            if six.PY3 and isinstance(chunk, bytes):
-                # in python 2.7, bytes were implicitly converted to strings
-                # in python 3.5 this is no longer the case so we need this
-                # code to manually convert it
+            if isinstance(chunk, bytes):
                 chunk = chunk.decode('utf-8')
             result += chunk
             if len(result) > cfg.CONF.max_response_size:
@@ -168,16 +164,18 @@ def format_node_name(fmt, cluster, index):
 
     result = ""
     last = 0
-    pattern = re.compile("(\$\d{0,8}[RI])")
+    pattern = re.compile("(\$\d{0,8}[rRI])")
     for m in pattern.finditer(fmt):
         group = m.group()
         t = group[-1]
         width = group[1:-1]
-        if t == "R":  # random string
+        if t == "R" or t == "r":  # random string
             if width != "":
                 sub = random_name(int(width))
             else:
                 sub = random_name(8)
+            if t == "r":
+                sub = sub.lower()
         elif t == "I":  # node index
             if width != "":
                 str_index = str(index)
@@ -215,7 +213,7 @@ def get_path_parser(path):
     try:
         expr = parse(path)
     except Exception as ex:
-        error_text = six.text_type(ex)
+        error_text = str(ex)
         error_msg = error_text.split(':', 1)[1]
         raise exception.BadRequest(
             msg=_("Invalid attribute path - %s") % error_msg.strip())
