@@ -120,7 +120,16 @@ class KeystoneClient(base.DriverBase):
             'user_domain_name': cfg.CONF.authentication.service_user_domain,
             'project_domain_name':
                 cfg.CONF.authentication.service_project_domain,
+            'verify': cfg.CONF.authentication.verify_ssl,
+            'interface': cfg.CONF.authentication.interface,
         }
+        if cfg.CONF.authentication.certfile and \
+           cfg.CONF.authentication.keyfile:
+            creds['cert'] = cfg.CONF.authentication.certfile
+            creds['key'] = cfg.CONF.authentication.keyfile
+        if cfg.CONF.authentication.cafile:
+            creds['cacert'] = cfg.CONF.authentication.cafile
+
         creds.update(**kwargs)
         return creds
 
@@ -147,8 +156,9 @@ class KeystoneClient(base.DriverBase):
     def get_senlin_endpoint(self):
         """Get Senlin service endpoint."""
         region = cfg.CONF.default_region_name
+        interface = cfg.CONF.authentication.interface
         base = self.conn.session.get_endpoint(service_type='clustering',
-                                              interface='public',
+                                              interface=interface,
                                               region_name=region)
 
         return base
