@@ -240,16 +240,17 @@ class ClusterAction(base.Action):
         for node_set in plan:
             child = []
             nodes = list(node_set)
+            nodes.sort()
 
             for node in nodes:
                 kwargs = {
                     'name': 'node_update_%s' % node[:8],
                     'cluster_id': self.entity.id,
                     'cause': consts.CAUSE_DERIVED,
-                    'inputs': {
-                        'new_profile_id': profile_id,
-                    },
+                    'inputs': self.entity.config,
                 }
+                kwargs['inputs']['new_profile_id'] = profile_id
+
                 action_id = base.Action.create(self.context, node,
                                                consts.NODE_UPDATE, **kwargs)
                 child.append(action_id)
@@ -299,6 +300,15 @@ class ClusterAction(base.Action):
         profile_only = self.inputs.get('profile_only')
 
         if config is not None:
+            # make sure config values are valid
+            try:
+                stop_timeout = config.get('cluster.stop_timeout_before_update')
+                if stop_timeout:
+                    config['cluster.stop_timeout_before_update'] = int(
+                        stop_timeout)
+            except Exception as e:
+                return self.RES_ERROR, str(e)
+
             self.entity.config = config
         if name is not None:
             self.entity.name = name
@@ -1215,6 +1225,12 @@ class ClusterAction(base.Action):
         """Handler to cancel the execution of action."""
         return self.RES_OK
 
+    def release_lock(self):
+        """Handler to release the lock."""
+        senlin_lock.cluster_lock_release(self.target, self.id,
+                                         senlin_lock.CLUSTER_SCOPE)
+        return self.RES_OK
+
 
 def CompleteLifecycleProc(context, action_id):
     """Complete lifecycle process."""
