@@ -11,7 +11,6 @@
 # under the License.
 
 from oslo_log import log as logging
-import six
 
 from senlin.common import consts
 from senlin.common import exception as exc
@@ -102,7 +101,7 @@ class StackProfile(base.Profile):
         self.stack_id = None
 
     def validate(self, validate_props=False):
-        '''Validate the schema and the data provided.'''
+        """Validate the schema and the data provided."""
         # general validation
         self.spec_data.validate()
         self.properties.validate()
@@ -136,7 +135,7 @@ class StackProfile(base.Profile):
         try:
             self.orchestration(obj).stack_create(**kwargs)
         except exc.InternalError as ex:
-            msg = _('Failed in validating template: %s') % six.text_type(ex)
+            msg = _('Failed in validating template: %s') % str(ex)
             raise exc.InvalidSpec(message=msg)
 
         return True
@@ -176,7 +175,8 @@ class StackProfile(base.Profile):
                                                    timeout=timeout)
             return stack.id
         except exc.InternalError as ex:
-            raise exc.EResourceCreation(type='stack', message=ex.message)
+            raise exc.EResourceCreation(type='stack',
+                                        message=str(ex))
 
     def do_delete(self, obj, **params):
         """Delete the physical stack behind the node object.
@@ -198,7 +198,7 @@ class StackProfile(base.Profile):
             self.orchestration(obj).wait_for_stack_delete(stack_id)
         except exc.InternalError as ex:
             raise exc.EResourceDeletion(type='stack', id=stack_id,
-                                        message=six.text_type(ex))
+                                        message=str(ex))
         return True
 
     def do_update(self, obj, new_profile, **params):
@@ -256,7 +256,7 @@ class StackProfile(base.Profile):
                               timeout=timeout)
         except exc.InternalError as ex:
             raise exc.EResourceUpdate(type='stack', id=self.stack_id,
-                                      message=ex.message)
+                                      message=str(ex))
 
         return True
 
@@ -282,7 +282,7 @@ class StackProfile(base.Profile):
         except exc.InternalError as ex:
             raise exc.EResourceOperation(op='checking', type='stack',
                                          id=stack_id,
-                                         message=six.text_type(ex))
+                                         message=str(ex))
 
         return True
 
@@ -297,7 +297,7 @@ class StackProfile(base.Profile):
             return {
                 'Error': {
                     'code': ex.code,
-                    'message': six.text_type(ex)
+                    'message': str(ex)
                 }
             }
 
@@ -328,7 +328,7 @@ class StackProfile(base.Profile):
             env = driver.stack_get_environment(obj.physical_id)
             files = driver.stack_get_files(obj.physical_id)
         except exc.InternalError as ex:
-            return {'Error': {'code': ex.code, 'message': six.text_type(ex)}}
+            return {'Error': {'code': ex.code, 'message': str(ex)}}
 
         spec = {
             self.ENVIRONMENT: env.to_dict(),
