@@ -11,7 +11,8 @@
 # under the License.
 
 import http.client as http_client
-import mock
+from unittest import mock
+
 from oslo_serialization import jsonutils
 from oslo_utils import encodeutils
 import webob
@@ -40,7 +41,7 @@ class VersionControllerTest(base.SenlinTestCase):
         environ = {
             'REQUEST_METHOD': 'GET',
             'SERVER_NAME': 'host',
-            'SERVER_PORT': 8778,
+            'SERVER_PORT': 8777,
             'SCRIPT_NAME': '/',
             'PATH_INFO': '/',
             'wsgi.url_scheme': 'http',
