@@ -10,7 +10,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import mock
+from unittest import mock
 
 from senlin.api.middleware import fault
 from senlin.api.openstack.v1 import build_info
