@@ -10,8 +10,9 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import mock
-import six
+import copy
+from unittest import mock
+
 from webob import exc
 
 from oslo_serialization import jsonutils
@@ -33,7 +34,7 @@ class NodeControllerTest(shared.ControllerTest, base.SenlinTestCase):
         super(NodeControllerTest, self).setUp()
 
         class DummyConfig(object):
-            bind_port = 8778
+            bind_port = 8777
 
         cfgopts = DummyConfig()
         self.controller = nodes.NodeController(options=cfgopts)
@@ -76,6 +77,90 @@ class NodeControllerTest(shared.ControllerTest, base.SenlinTestCase):
         mock_call.assert_called_once_with(
             req.context, 'node_list', obj)
 
+    @mock.patch.object(util, 'parse_request')
+    @mock.patch.object(rpc_client.EngineClient, 'call')
+    def test_node_index_without_tainted(self, mock_call, mock_parse,
+                                        mock_enforce):
+        self._mock_enforce_setup(mock_enforce, 'index', True)
+        req = self._get('/nodes', version='1.12')
+
+        engine_resp = [
+            {
+                u'id': u'aaaa-bbbb-cccc',
+                u'name': u'node-1',
+                u'cluster_id': None,
+                u'physical_id': None,
+                u'profile_id': u'pppp-rrrr-oooo-ffff',
+                u'profile_name': u'my_stack_profile',
+                u'index': 1,
+                u'role': None,
+                u'init_time': u'2015-01-23T13:06:00Z',
+                u'created_time': u'2015-01-23T13:07:22Z',
+                u'updated_time': None,
+                u'status': u'ACTIVE',
+                u'status_reason': u'Node successfully created',
+                u'data': {},
+                u'metadata': {},
+                u'tainted': False,
+            }
+        ]
+
+        obj = mock.Mock()
+        mock_parse.return_value = obj
+        mock_call.return_value = copy.deepcopy(engine_resp)
+
+        result = self.controller.index(req)
+
+        # list call for version 1.12 should have tainted field removed
+        # remove tainted field from expected response
+        engine_resp[0].pop('tainted')
+
+        self.assertEqual(engine_resp, result['nodes'])
+        mock_parse.assert_called_once_with(
+            'NodeListRequest', req, {'project_safe': True})
+        mock_call.assert_called_once_with(
+            req.context, 'node_list', obj)
+
+    @mock.patch.object(util, 'parse_request')
+    @mock.patch.object(rpc_client.EngineClient, 'call')
+    def test_node_index_with_tainted(self, mock_call, mock_parse,
+                                     mock_enforce):
+        self._mock_enforce_setup(mock_enforce, 'index', True)
+        req = self._get('/nodes', version='1.13')
+
+        engine_resp = [
+            {
+                u'id': u'aaaa-bbbb-cccc',
+                u'name': u'node-1',
+                u'cluster_id': None,
+                u'physical_id': None,
+                u'profile_id': u'pppp-rrrr-oooo-ffff',
+                u'profile_name': u'my_stack_profile',
+                u'index': 1,
+                u'role': None,
+                u'init_time': u'2015-01-23T13:06:00Z',
+                u'created_time': u'2015-01-23T13:07:22Z',
+                u'updated_time': None,
+                u'status': u'ACTIVE',
+                u'status_reason': u'Node successfully created',
+                u'data': {},
+                u'metadata': {},
+                u'tainted': False,
+            }
+        ]
+
+        obj = mock.Mock()
+        mock_parse.return_value = obj
+        mock_call.return_value = copy.deepcopy(engine_resp)
+
+        result = self.controller.index(req)
+
+        self.assertEqual(engine_resp, result['nodes'])
+        mock_parse.assert_called_once_with(
+            'NodeListRequest', req, {'project_safe': True})
+        mock_call.assert_called_once_with(
+            req.context, 'node_list', obj)
+
     @mock.patch.object(util, 'parse_request')
     @mock.patch.object(rpc_client.EngineClient, 'call')
     def test_node_index_whitelists_params(self, mock_call,
@@ -188,7 +273,7 @@ class NodeControllerTest(shared.ControllerTest, base.SenlinTestCase):
                                self.controller.index, req)
 
         self.assertEqual("Invalid value 'No' specified for 'global_project'",
-                         six.text_type(ex))
+                         str(ex))
         self.assertFalse(mock_parse.called)
         self.assertFalse(mock_call.called)
 
@@ -204,7 +289,7 @@ class NodeControllerTest(shared.ControllerTest, base.SenlinTestCase):
         ex = self.assertRaises(exc.HTTPBadRequest,
                                self.controller.index, req)
 
-        self.assertEqual("bad limit", six.text_type(ex))
+        self.assertEqual("bad limit", str(ex))
         mock_parse.assert_called_once_with(
             'NodeListRequest', req,
             {'limit': 'not-int', 'project_safe': True})
@@ -244,7 +329,7 @@ class NodeControllerTest(shared.ControllerTest, base.SenlinTestCase):
         resp = shared.request_with_middleware(fault.FaultWrapper,
                                               self.controller.index, req)
         self.assertEqual(403, resp.status_int)
-        self.assertIn('403 Forbidden', six.text_type(resp))
+        self.assertIn('403 Forbidden', str(resp))
 
     @mock.patch.object(util, 'parse_request')
     @mock.patch.object(rpc_client.EngineClient, 'call')
@@ -300,7 +385,7 @@ class NodeControllerTest(shared.ControllerTest, base.SenlinTestCase):
                                self.controller.create,
                                req, body=body)
 
-        self.assertEqual("bad param", six.text_type(ex))
+        self.assertEqual("bad param", str(ex))
         mock_parse.assert_called_once_with(
             'NodeCreateRequest', req, body, 'node')
         self.assertFalse(mock_call.called)
@@ -323,7 +408,7 @@ class NodeControllerTest(shared.ControllerTest, base.SenlinTestCase):
         ex = self.assertRaises(exc.HTTPBadRequest,
                                self.controller.create,
                                req, body=body)
-        self.assertEqual("miss profile", six.text_type(ex))
+        self.assertEqual("miss profile", str(ex))
         mock_parse.assert_called_once_with(
             'NodeCreateRequest', req, body, 'node')
         self.assertFalse(mock_call.called)
@@ -345,7 +430,7 @@ class NodeControllerTest(shared.ControllerTest, base.SenlinTestCase):
         ex = self.assertRaises(exc.HTTPBadRequest,
                                self.controller.create,
                                req, body=body)
-        self.assertEqual("miss name", six.text_type(ex))
+        self.assertEqual("miss name", str(ex))
         mock_parse.assert_called_once_with(
             'NodeCreateRequest', req, body, 'node')
         self.assertFalse(mock_call.called)
@@ -527,7 +612,7 @@ class NodeControllerTest(shared.ControllerTest, base.SenlinTestCase):
                                req, node_id=node_id)
 
         self.assertEqual("Invalid value 'Okay' specified for 'show_details'",
-                         six.text_type(ex))
+                         str(ex))
         self.assertFalse(mock_parse.called)
         self.assertFalse(mock_call.called)
 
@@ -563,7 +648,7 @@ class NodeControllerTest(shared.ControllerTest, base.SenlinTestCase):
                                               req, node_id=node_id)
 
         self.assertEqual(403, resp.status_int)
-        self.assertIn('403 Forbidden', six.text_type(resp))
+        self.assertIn('403 Forbidden', str(resp))
 
     @mock.patch.object(util, 'parse_request')
     @mock.patch.object(rpc_client.EngineClient, 'call')
@@ -624,7 +709,7 @@ class NodeControllerTest(shared.ControllerTest, base.SenlinTestCase):
                                self.controller.update, req,
                                node_id=nid, body=body)
         self.assertEqual("Malformed request data, missing 'node' key "
-                         "in request body.", six.text_type(ex))
+                         "in request body.", str(ex))
         self.assertFalse(mock_parse.called)
         self.assertFalse(mock_call.called)
 
@@ -709,7 +794,7 @@ class NodeControllerTest(shared.ControllerTest, base.SenlinTestCase):
                                self.controller.update,
                                req, node_id=nid, body=body)
 
-        self.assertEqual("miss cluster", six.text_type(ex))
+        self.assertEqual("miss cluster", str(ex))
         mock_parse.assert_called_once_with(
             'NodeUpdateRequest', req, mock.ANY)
         self.assertFalse(mock_call.called)
@@ -733,7 +818,7 @@ class NodeControllerTest(shared.ControllerTest, base.SenlinTestCase):
                                               req, node_id=node_id, body=body)
 
         self.assertEqual(403, resp.status_int)
-        self.assertIn('403 Forbidden', six.text_type(resp))
+        self.assertIn('403 Forbidden', str(resp))
 
     @mock.patch.object(util, 'parse_request')
     @mock.patch.object(rpc_client.EngineClient, 'call')
@@ -769,7 +854,7 @@ class NodeControllerTest(shared.ControllerTest, base.SenlinTestCase):
         ex = self.assertRaises(exc.HTTPBadRequest,
                                self.controller.delete, req,
                                node_id=nid)
-        self.assertEqual("bad node", six.text_type(ex))
+        self.assertEqual("bad node", str(ex))
         self.assertFalse(mock_call.called)
         mock_parse.assert_called_once_with(
             'NodeDeleteRequest', req, {'identity': nid, 'force': False})
@@ -785,7 +870,7 @@ class NodeControllerTest(shared.ControllerTest, base.SenlinTestCase):
                                               req, node_id=nid)
 
         self.assertEqual(403, resp.status_int)
-        self.assertIn('403 Forbidden', six.text_type(resp))
+        self.assertIn('403 Forbidden', str(resp))
 
     @mock.patch.object(util, 'parse_request')
     @mock.patch.object(rpc_client.EngineClient, 'call')
@@ -933,7 +1018,7 @@ class NodeControllerTest(shared.ControllerTest, base.SenlinTestCase):
                                self.controller.action,
                                req, node_id=node_id, body=body)
         self.assertEqual("The params provided is not a map.",
-                         six.text_type(ex))
+                         str(ex))
         self.assertFalse(mock_parse.called)
         self.assertFalse(mock_call.called)
 
@@ -954,7 +1039,7 @@ class NodeControllerTest(shared.ControllerTest, base.SenlinTestCase):
         self.assertFalse(mock_parse.called)
         self.assertFalse(mock_call.called)
         self.assertEqual(400, ex.code)
-        self.assertIn('No action specified.', six.text_type(ex))
+        self.assertIn('No action specified.', str(ex))
 
     @mock.patch.object(util, 'parse_request')
     @mock.patch.object(rpc_client.EngineClient, 'call')
@@ -973,7 +1058,7 @@ class NodeControllerTest(shared.ControllerTest, base.SenlinTestCase):
         self.assertFalse(mock_parse.called)
         self.assertFalse(mock_call.called)
         self.assertEqual(400, ex.code)
-        self.assertIn('Multiple actions specified.', six.text_type(ex))
+        self.assertIn('Multiple actions specified.', str(ex))
 
     @mock.patch.object(util, 'parse_request')
     @mock.patch.object(rpc_client.EngineClient, 'call')
@@ -993,7 +1078,7 @@ class NodeControllerTest(shared.ControllerTest, base.SenlinTestCase):
         self.assertFalse(mock_call.called)
         self.assertEqual(400, ex.code)
         self.assertIn("Unrecognized action 'eat' specified",
-                      six.text_type(ex))
+                      str(ex))
 
     @mock.patch.object(util, 'parse_request')
     @mock.patch.object(rpc_client.EngineClient, 'call')
@@ -1009,11 +1094,13 @@ class NodeControllerTest(shared.ControllerTest, base.SenlinTestCase):
         mock_parse.return_value = obj
         mock_call.return_value = engine_response
 
-        response = self.controller.operation(req, node_id=node_id, body=body)
+        response = self.controller.operation(req, node_id=node_id,
+                                             body=body)
 
-        location = {'location': '/actions/action-id'}
-        engine_response.update(location)
-        self.assertEqual(engine_response, response)
+        expected_response = {'location': '/actions/action-id',
+                             'action': 'action-id'}
+
+        self.assertEqual(response, expected_response)
         mock_parse.assert_called_once_with(
             'NodeOperationRequest', req,
             {'identity': 'xxxx-yyyy',
@@ -1033,7 +1120,7 @@ class NodeControllerTest(shared.ControllerTest, base.SenlinTestCase):
                                req, node_id=node_id, body=body)
 
         self.assertEqual("API version '1.3' is not supported on this "
-                         "method.", six.text_type(ex))
+                         "method.", str(ex))
 
     def test_node_operation_missing_operation(self, mock_enforce):
         self._mock_enforce_setup(mock_enforce, 'operation', True)
@@ -1047,7 +1134,7 @@ class NodeControllerTest(shared.ControllerTest, base.SenlinTestCase):
                                node_id=node_id, body=body)
 
         self.assertEqual(400, ex.code)
-        self.assertIn('No operation specified.', six.text_type(ex))
+        self.assertIn('No operation specified.', str(ex))
 
     def test_node_operation_multiple_operation(self, mock_enforce):
         self._mock_enforce_setup(mock_enforce, 'operation', True)
@@ -1061,4 +1148,4 @@ class NodeControllerTest(shared.ControllerTest, base.SenlinTestCase):
                                req, node_id=node_id, body=body)
 
         self.assertEqual(400, ex.code)
-        self.assertIn('Multiple operations specified.', six.text_type(ex))
+        self.assertIn('Multiple operations specified.', str(ex))
