@@ -10,7 +10,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import mock
+from unittest import mock
 
 from oslo_db.sqlalchemy import utils as sa_utils
 from oslo_utils import timeutils as tu
