@@ -10,7 +10,8 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import mock
+from unittest import mock
+
 from oslo_db.sqlalchemy import utils as sa_utils
 from oslo_utils import timeutils as tu
 
@@ -32,9 +33,9 @@ class DBAPIClusterPolicyTest(base.SenlinTestCase):
         data = {
             'name': 'test_policy',
             'type': 'ScalingPolicy',
-            'user': self.ctx.user,
-            'project': self.ctx.project,
-            'domain': self.ctx.domain,
+            'user': self.ctx.user_id,
+            'project': self.ctx.project_id,
+            'domain': self.ctx.domain_id,
             'spec': {
                 'min_size': 1,
                 'max_size': 10,
