@@ -10,10 +10,10 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import mock
+from unittest import mock
 
-from senlin.drivers.openstack import cinder_v2
-from senlin.drivers.openstack import sdk
+from senlin.drivers.os import cinder_v2
+from senlin.drivers import sdk
 from senlin.tests.unit.common import base
 from senlin.tests.unit.common import utils
 
