@@ -10,8 +10,9 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import copy
 import eventlet
-import mock
+from unittest import mock
 
 from oslo_context import context as oslo_context
 
@@ -50,7 +51,11 @@ class TestOctaviaLBaaSDriver(base.SenlinTestCase):
         self.pool = {
             'lb_method': 'ROUND_ROBIN',
             'protocol': 'HTTP',
-            'admin_state_up': True
+            'session_persistence': {
+                'type': 'SOURCE_IP',
+                'cookie_name': 'whatever',
+            },
+            'admin_state_up': True,
         }
         self.hm = {
             "type": "HTTP",
@@ -63,6 +68,8 @@ class TestOctaviaLBaaSDriver(base.SenlinTestCase):
             "url_path": "/index.html",
             "expected_codes": "200,201,202"
         }
+        self.availability_zone = 'my_fake_az'
+        self.flavor_id = 'my_fake_flavor_id'
 
     def test_init(self):
         conn_params = self.context.to_dict()
@@ -127,7 +134,7 @@ class TestOctaviaLBaaSDriver(base.SenlinTestCase):
         self.assertFalse(res)
         mock_sleep.assert_called_once_with(10)
 
-    def test_lb_create_succeeded(self):
+    def test_lb_create_succeeded_session_persistence_none(self):
         lb_obj = mock.Mock()
         listener_obj = mock.Mock()
         pool_obj = mock.Mock()
@@ -141,6 +148,7 @@ class TestOctaviaLBaaSDriver(base.SenlinTestCase):
         subnet_obj.id = 'SUBNET_ID'
         subnet_obj.network_id = 'NETWORK_ID'
         hm_obj.id = 'HEALTHMONITOR_ID'
+        cluster_name = 'test_cluster'
 
         self.oc.loadbalancer_create.return_value = lb_obj
         self.oc.listener_create.return_value = listener_obj
@@ -150,20 +158,158 @@ class TestOctaviaLBaaSDriver(base.SenlinTestCase):
 
         self.lb_driver._wait_for_lb_ready = mock.Mock()
         self.lb_driver._wait_for_lb_ready.return_value = True
-        status, res = self.lb_driver.lb_create(self.vip, self.pool, self.hm)
+        temp_pool = copy.deepcopy(self.pool)
+        temp_pool['session_persistence'] = {}
+        status, res = self.lb_driver.lb_create(self.vip, temp_pool,
+                                               cluster_name, self.hm,
+                                               self.availability_zone,
+                                               self.flavor_id)
 
         self.assertTrue(status)
+        lb_name = 'senlin-lb-%s' % cluster_name
         self.oc.loadbalancer_create.assert_called_once_with(
-            'SUBNET_ID', self.vip['address'], self.vip['admin_state_up'])
+            'SUBNET_ID', None, self.vip['address'], self.vip['admin_state_up'],
+            name=lb_name, availability_zone=self.availability_zone,
+            flavor_id=self.flavor_id)
         self.assertEqual('LB_ID', res['loadbalancer'])
         self.assertEqual('192.168.1.100', res['vip_address'])
+        listener_name = 'senlin-listener-%s' % cluster_name
         self.oc.listener_create.assert_called_once_with(
             'LB_ID', self.vip['protocol'], self.vip['protocol_port'],
-            self.vip['connection_limit'], self.vip['admin_state_up'])
+            self.vip['connection_limit'], self.vip['admin_state_up'],
+            name=listener_name)
         self.assertEqual('LISTENER_ID', res['listener'])
+        pool_name = 'senlin-pool-%s' % cluster_name
+        self.oc.pool_create.assert_called_once_with(
+            temp_pool['lb_method'], 'LISTENER_ID', temp_pool['protocol'],
+            temp_pool['session_persistence'], temp_pool['admin_state_up'],
+            name=pool_name)
+        self.assertEqual('POOL_ID', res['pool'])
+        self.oc.healthmonitor_create.assert_called_once_with(
+            self.hm['type'], self.hm['delay'], self.hm['timeout'],
+            self.hm['max_retries'], 'POOL_ID', self.hm['admin_state_up'],
+            self.hm['http_method'], self.hm['url_path'],
+            self.hm['expected_codes'])
+        self.assertEqual('HEALTHMONITOR_ID', res['healthmonitor'])
+        self.lb_driver._wait_for_lb_ready.assert_called_with('LB_ID')
+        calls = [mock.call('LB_ID') for i in range(1, 5)]
+        self.lb_driver._wait_for_lb_ready.assert_has_calls(
+            calls, any_order=False)
+
+    def test_lb_create_succeeded_subnet(self):
+        lb_obj = mock.Mock()
+        listener_obj = mock.Mock()
+        pool_obj = mock.Mock()
+        hm_obj = mock.Mock()
+        lb_obj.id = 'LB_ID'
+        lb_obj.vip_address = '192.168.1.100'
+        listener_obj.id = 'LISTENER_ID'
+        pool_obj.id = 'POOL_ID'
+        subnet_obj = mock.Mock()
+        subnet_obj.name = 'subnet'
+        subnet_obj.id = 'SUBNET_ID'
+        subnet_obj.network_id = 'NETWORK_ID'
+        hm_obj.id = 'HEALTHMONITOR_ID'
+        cluster_name = 'test_cluster'
+
+        self.oc.loadbalancer_create.return_value = lb_obj
+        self.oc.listener_create.return_value = listener_obj
+        self.oc.pool_create.return_value = pool_obj
+        self.oc.healthmonitor_create.return_value = hm_obj
+        self.nc.subnet_get.return_value = subnet_obj
+
+        self.lb_driver._wait_for_lb_ready = mock.Mock()
+        self.lb_driver._wait_for_lb_ready.return_value = True
+        status, res = self.lb_driver.lb_create(self.vip, self.pool,
+                                               cluster_name, self.hm,
+                                               self.availability_zone,
+                                               self.flavor_id)
+
+        self.assertTrue(status)
+        lb_name = 'senlin-lb-%s' % cluster_name
+        self.oc.loadbalancer_create.assert_called_once_with(
+            'SUBNET_ID', None, self.vip['address'], self.vip['admin_state_up'],
+            name=lb_name, availability_zone=self.availability_zone,
+            flavor_id=self.flavor_id)
+        self.assertEqual('LB_ID', res['loadbalancer'])
+        self.assertEqual('192.168.1.100', res['vip_address'])
+        listener_name = 'senlin-listener-%s' % cluster_name
+        self.oc.listener_create.assert_called_once_with(
+            'LB_ID', self.vip['protocol'], self.vip['protocol_port'],
+            self.vip['connection_limit'], self.vip['admin_state_up'],
+            name=listener_name)
+        self.assertEqual('LISTENER_ID', res['listener'])
+        pool_name = 'senlin-pool-%s' % cluster_name
         self.oc.pool_create.assert_called_once_with(
             self.pool['lb_method'], 'LISTENER_ID', self.pool['protocol'],
-            self.pool['admin_state_up'])
+            self.pool['session_persistence'], self.pool['admin_state_up'],
+            name=pool_name)
+        self.assertEqual('POOL_ID', res['pool'])
+        self.oc.healthmonitor_create.assert_called_once_with(
+            self.hm['type'], self.hm['delay'], self.hm['timeout'],
+            self.hm['max_retries'], 'POOL_ID', self.hm['admin_state_up'],
+            self.hm['http_method'], self.hm['url_path'],
+            self.hm['expected_codes'])
+        self.assertEqual('HEALTHMONITOR_ID', res['healthmonitor'])
+        self.lb_driver._wait_for_lb_ready.assert_called_with('LB_ID')
+        calls = [mock.call('LB_ID') for i in range(1, 5)]
+        self.lb_driver._wait_for_lb_ready.assert_has_calls(
+            calls, any_order=False)
+
+    def test_lb_create_succeeded_network(self):
+        vip = {
+            'network': 'network-01',
+            'address': '192.168.1.100',
+            'admin_state_up': True,
+            'protocol': 'HTTP',
+            'protocol_port': 80,
+            'connection_limit': 50
+        }
+        lb_obj = mock.Mock()
+        listener_obj = mock.Mock()
+        pool_obj = mock.Mock()
+        hm_obj = mock.Mock()
+        lb_obj.id = 'LB_ID'
+        lb_obj.vip_address = '192.168.1.100'
+        listener_obj.id = 'LISTENER_ID'
+        pool_obj.id = 'POOL_ID'
+        network_obj = mock.Mock()
+        network_obj.name = 'network'
+        network_obj.id = 'NETWORK_ID'
+        hm_obj.id = 'HEALTHMONITOR_ID'
+        cluster_name = 'test_cluster'
+
+        self.oc.loadbalancer_create.return_value = lb_obj
+        self.oc.listener_create.return_value = listener_obj
+        self.oc.pool_create.return_value = pool_obj
+        self.oc.healthmonitor_create.return_value = hm_obj
+        self.nc.network_get.return_value = network_obj
+
+        self.lb_driver._wait_for_lb_ready = mock.Mock()
+        self.lb_driver._wait_for_lb_ready.return_value = True
+        status, res = self.lb_driver.lb_create(vip, self.pool,
+                                               cluster_name, self.hm,
+                                               self.availability_zone)
+
+        self.assertTrue(status)
+        lb_name = 'senlin-lb-%s' % cluster_name
+        self.oc.loadbalancer_create.assert_called_once_with(
+            None, 'NETWORK_ID', vip['address'], vip['admin_state_up'],
+            name=lb_name, availability_zone=self.availability_zone,
+            flavor_id=None)
+        self.assertEqual('LB_ID', res['loadbalancer'])
+        self.assertEqual('192.168.1.100', res['vip_address'])
+        listener_name = 'senlin-listener-%s' % cluster_name
+        self.oc.listener_create.assert_called_once_with(
+            'LB_ID', vip['protocol'], vip['protocol_port'],
+            vip['connection_limit'], vip['admin_state_up'],
+            name=listener_name)
+        self.assertEqual('LISTENER_ID', res['listener'])
+        pool_name = 'senlin-pool-%s' % cluster_name
+        self.oc.pool_create.assert_called_once_with(
+            self.pool['lb_method'], 'LISTENER_ID', self.pool['protocol'],
+            self.pool['session_persistence'], self.pool['admin_state_up'],
+            name=pool_name)
         self.assertEqual('POOL_ID', res['pool'])
         self.oc.healthmonitor_create.assert_called_once_with(
             self.hm['type'], self.hm['delay'], self.hm['timeout'],
@@ -183,6 +329,7 @@ class TestOctaviaLBaaSDriver(base.SenlinTestCase):
         subnet_obj.name = 'subnet'
         subnet_obj.id = 'SUBNET_ID'
         subnet_obj.network_id = 'NETWORK_ID'
+        cluster_name = 'test_cluster'
         self.oc.loadbalancer_create.return_value = lb_obj
         self.nc.subnet_get.return_value = subnet_obj
 
@@ -190,12 +337,15 @@ class TestOctaviaLBaaSDriver(base.SenlinTestCase):
         self.lb_driver._wait_for_lb_ready.side_effect = [False]
         self.lb_driver.lb_delete = mock.Mock()
 
-        status, res = self.lb_driver.lb_create(self.vip, self.pool, self.hm)
+        status, res = self.lb_driver.lb_create(self.vip, self.pool,
+                                               cluster_name, self.hm)
         self.assertFalse(status)
         msg = _('Failed in creating loadbalancer (%s).') % 'LB_ID'
         self.assertEqual(msg, res)
+        lb_name = 'senlin-lb-%s' % cluster_name
         self.oc.loadbalancer_create.assert_called_once_with(
-            'SUBNET_ID', self.vip['address'], self.vip['admin_state_up'])
+            'SUBNET_ID', None, self.vip['address'], self.vip['admin_state_up'],
+            availability_zone=None, name=lb_name, flavor_id=None)
         self.lb_driver._wait_for_lb_ready.assert_called_once_with('LB_ID')
         self.lb_driver.lb_delete.assert_called_once_with(
             loadbalancer='LB_ID')
@@ -227,6 +377,7 @@ class TestOctaviaLBaaSDriver(base.SenlinTestCase):
         subnet_obj.name = 'subnet'
         subnet_obj.id = 'SUBNET_ID'
         subnet_obj.network_id = 'NETWORK_ID'
+        cluster_name = 'test_cluster'
 
         self.lb_driver._wait_for_lb_ready = mock.Mock()
         self.lb_driver._wait_for_lb_ready.side_effect = [True, False]
@@ -235,15 +386,20 @@ class TestOctaviaLBaaSDriver(base.SenlinTestCase):
         self.nc.subnet_get.return_value = subnet_obj
         self.lb_driver.lb_delete = mock.Mock()
 
-        status, res = self.lb_driver.lb_create(self.vip, self.pool, self.hm)
+        status, res = self.lb_driver.lb_create(self.vip, self.pool,
+                                               cluster_name, self.hm)
         self.assertFalse(status)
         msg = _('Failed in creating listener (%s).') % 'LISTENER_ID'
         self.assertEqual(msg, res)
+        lb_name = 'senlin-lb-%s' % cluster_name
         self.oc.loadbalancer_create.assert_called_once_with(
-            'SUBNET_ID', self.vip['address'], self.vip['admin_state_up'])
+            'SUBNET_ID', None, self.vip['address'], self.vip['admin_state_up'],
+            availability_zone=None, name=lb_name, flavor_id=None)
+        listener_name = 'senlin-listener-%s' % cluster_name
         self.oc.listener_create.assert_called_once_with(
             'LB_ID', self.vip['protocol'], self.vip['protocol_port'],
-            self.vip['connection_limit'], self.vip['admin_state_up'])
+            self.vip['connection_limit'], self.vip['admin_state_up'],
+            name=listener_name)
         self.lb_driver._wait_for_lb_ready.assert_called_with('LB_ID')
         self.lb_driver.lb_delete.assert_called_once_with(
             loadbalancer='LB_ID', listener='LISTENER_ID')
@@ -270,6 +426,7 @@ class TestOctaviaLBaaSDriver(base.SenlinTestCase):
         subnet_obj.name = 'subnet'
         subnet_obj.id = 'SUBNET_ID'
         subnet_obj.network_id = 'NETWORK_ID'
+        cluster_name = 'test_cluster'
 
         self.lb_driver._wait_for_lb_ready = mock.Mock()
         self.lb_driver._wait_for_lb_ready.side_effect = [True, True, False]
@@ -279,18 +436,25 @@ class TestOctaviaLBaaSDriver(base.SenlinTestCase):
         self.nc.subnet_get.return_value = subnet_obj
         self.lb_driver.lb_delete = mock.Mock()
 
-        status, res = self.lb_driver.lb_create(self.vip, self.pool, self.hm)
+        status, res = self.lb_driver.lb_create(self.vip, self.pool,
+                                               cluster_name, self.hm)
         self.assertFalse(status)
         msg = _('Failed in creating pool (%s).') % 'POOL_ID'
         self.assertEqual(msg, res)
+        lb_name = 'senlin-lb-%s' % cluster_name
         self.oc.loadbalancer_create.assert_called_once_with(
-            'SUBNET_ID', self.vip['address'], self.vip['admin_state_up'])
+            'SUBNET_ID', None, self.vip['address'], self.vip['admin_state_up'],
+            availability_zone=None, name=lb_name, flavor_id=None)
+        listener_name = 'senlin-listener-%s' % cluster_name
         self.oc.listener_create.assert_called_once_with(
             'LB_ID', self.vip['protocol'], self.vip['protocol_port'],
-            self.vip['connection_limit'], self.vip['admin_state_up'])
+            self.vip['connection_limit'], self.vip['admin_state_up'],
+            name=listener_name)
+        pool_name = 'senlin-pool-%s' % cluster_name
         self.oc.pool_create.assert_called_once_with(
             self.pool['lb_method'], 'LISTENER_ID', self.pool['protocol'],
-            self.pool['admin_state_up'])
+            self.pool['session_persistence'], self.pool['admin_state_up'],
+            name=pool_name)
         self.lb_driver._wait_for_lb_ready.assert_called_with('LB_ID')
         self.lb_driver.lb_delete.assert_called_once_with(
             loadbalancer='LB_ID', listener='LISTENER_ID', pool='POOL_ID')
@@ -318,6 +482,7 @@ class TestOctaviaLBaaSDriver(base.SenlinTestCase):
         subnet_obj.id = 'SUBNET_ID'
         subnet_obj.network_id = 'NETWORK_ID'
         hm_obj.id = 'HEALTHMONITOR_ID'
+        cluster_name = 'test_cluster'
 
         self.lb_driver._wait_for_lb_ready = mock.Mock()
         self.lb_driver._wait_for_lb_ready.side_effect = [True, True,
@@ -329,7 +494,8 @@ class TestOctaviaLBaaSDriver(base.SenlinTestCase):
         self.nc.subnet_get.return_value = subnet_obj
         self.lb_driver.lb_delete = mock.Mock()
 
-        status, res = self.lb_driver.lb_create(self.vip, self.pool, self.hm)
+        status, res = self.lb_driver.lb_create(self.vip, self.pool,
+                                               cluster_name, self.hm)
         self.assertFalse(status)
         msg = _('Failed in creating health monitor (%s).') % 'HEALTHMONITOR_ID'
         self.assertEqual(msg, res)
@@ -342,7 +508,8 @@ class TestOctaviaLBaaSDriver(base.SenlinTestCase):
         self.lb_driver._wait_for_lb_ready.side_effect = [True, True, True]
         self.oc.healthmonitor_create.side_effect = exception.InternalError(
             code=500, message='CREATE FAILED')
-        status, res = self.lb_driver.lb_create(self.vip, self.pool, self.hm)
+        status, res = self.lb_driver.lb_create(self.vip, self.pool,
+                                               cluster_name, self.hm)
         self.assertFalse(status)
         msg = _('Failed in creating lb health monitor: CREATE FAILED.')
         self.assertEqual(msg, res)
@@ -459,6 +626,7 @@ class TestOctaviaLBaaSDriver(base.SenlinTestCase):
                 'network2': [{'addr': 'ipaddr_net2', 'version': '4'}]
             }
         }
+        name = node_detail.get('name')
         mock_pb_load.return_value.do_get_details.return_value = node_detail
 
         self.nc.subnet_get.return_value = subnet_obj
@@ -473,7 +641,7 @@ class TestOctaviaLBaaSDriver(base.SenlinTestCase):
         self.nc.network_get.assert_called_once_with('NETWORK_ID')
         # Make sure the ip matches with subnet ip_version
         self.oc.pool_member_create.assert_called_once_with(
-            pool_id, 'ipaddr2_net1', port, 'SUBNET_ID')
+            name, pool_id, 'ipaddr2_net1', port, 'SUBNET_ID')
         self.lb_driver._wait_for_lb_ready.assert_has_calls(
             [mock.call('LB_ID'), mock.call('LB_ID')])
 
