@@ -10,19 +10,21 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-'''
+"""
 A module that contains various fake entities
-'''
+"""
 
 from senlin.common import schema
 from senlin.policies import base as policy_base
 from senlin.profiles import base as profile_base
-from senlin.triggers import base as trigger_base
 
 
 class TestProfile(profile_base.Profile):
+
     CONTEXT = 'context'
+
     properties_schema = {
+        CONTEXT: schema.Map("context property"),
         'INT': schema.Integer('int property', default=0),
         'STR': schema.String('string property', default='a string'),
         'MAP': schema.Map(
@@ -38,9 +40,15 @@ class TestProfile(profile_base.Profile):
         ),
     }
 
+    OPERATIONS = {}
+
     def __init__(self, name, spec, **kwargs):
         super(TestProfile, self).__init__(name, spec, **kwargs)
 
+    @classmethod
+    def delete(cls, ctx, profile_id):
+        super(TestProfile, cls).delete(ctx, profile_id)
+
     def do_create(self):
         return {}
 
@@ -68,7 +76,7 @@ class TestPolicy(policy_base.Policy):
     def __init__(self, name, spec, **kwargs):
         super(TestPolicy, self).__init__(name, spec, **kwargs)
 
-    def attach(self, cluster):
+    def attach(self, cluster, enabled=True):
         return True, {}
 
     def detach(self, cluster):
@@ -79,16 +87,3 @@ class TestPolicy(policy_base.Policy):
 
     def post_op(self, cluster_id, action):
         return
-
-
-class TestTrigger(trigger_base.Trigger):
-    rule_schema = {
-        'KEY1': schema.String('key1', default='default1'),
-        'KEY2': schema.Integer('key2', default=1),
-    }
-
-    def __init__(self, name, spec, **kwargs):
-        super(TestTrigger, self).__init__(name, spec, **kwargs)
-        rule_spec = spec.get('rule', {})
-        self.rule = schema.Spec(self.rule_schema, rule_spec)
-        self.namespace = 'test'
