@@ -12,9 +12,8 @@
 
 from collections import namedtuple
 import copy
+from unittest import mock
 
-import mock
-import six
 
 from oslo_config import cfg
 
@@ -36,7 +35,7 @@ class TestHealthPolicy(base.SenlinTestCase):
 
         self.spec = {
             'type': 'senlin.policy.health',
-            'version': '1.1',
+            'version': '1.2',
             'properties': {
                 'detection': {
                     "detection_modes": [
@@ -61,7 +60,7 @@ class TestHealthPolicy(base.SenlinTestCase):
         fake_cluster = mock.Mock(id='CLUSTER_ID', nodes=[fake_node],
                                  rt={'profile': fake_profile})
         self.cluster = fake_cluster
-        self.patch('senlin.rpc.client.EngineClient')
+        self.patch('senlin.rpc.client.get_engine_client')
         self.hp = health_policy.HealthPolicy('test-policy', self.spec)
 
     def test_policy_init(self):
@@ -83,7 +82,7 @@ class TestHealthPolicy(base.SenlinTestCase):
 
         spec = {
             'type': 'senlin.policy.health',
-            'version': '1.1',
+            'version': '1.2',
             'properties': {
                 'detection': {
                     "detection_modes": [
@@ -106,7 +105,7 @@ class TestHealthPolicy(base.SenlinTestCase):
 
         self.assertIsNone(hp.id)
         self.assertEqual('test-policy', hp.name)
-        self.assertEqual('senlin.policy.health-1.1', hp.type)
+        self.assertEqual('senlin.policy.health-1.2', hp.type)
         self.assertEqual(detection_modes, hp.detection_modes)
         self.assertEqual(60, hp.interval)
         self.assertEqual([{'name': 'REBUILD', 'params': None}],
@@ -115,13 +114,16 @@ class TestHealthPolicy(base.SenlinTestCase):
     def test_policy_init_ops(self):
         spec = {
             'type': 'senlin.policy.health',
-            'version': '1.1',
+            'version': '1.2',
             'properties': {
                 'detection': {
                     "detection_modes": [
                         {
                             'type': 'NODE_STATUS_POLLING'
                         },
+                        {
+                            'type': 'HYPERVISOR_STATUS_POLLING'
+                        },
                         {
                             'type': 'NODE_STATUS_POLL_URL'
                         },
@@ -149,7 +151,7 @@ class TestHealthPolicy(base.SenlinTestCase):
             # check result
             self.assertIsNone(hp.id)
             self.assertEqual('test-policy', hp.name)
-            self.assertEqual('senlin.policy.health-1.1', hp.type)
+            self.assertEqual('senlin.policy.health-1.2', hp.type)
             self.assertEqual(60, hp.interval)
             self.assertEqual([{'name': 'REBUILD', 'params': None}],
                              hp.recover_actions)
@@ -166,7 +168,7 @@ class TestHealthPolicy(base.SenlinTestCase):
                                self.context)
 
         self.assertEqual("Only one 'actions' is supported for now.",
-                         six.text_type(ex))
+                         str(ex))
 
     def test_validate_valid_interval(self):
         spec = copy.deepcopy(self.spec)
@@ -192,7 +194,7 @@ class TestHealthPolicy(base.SenlinTestCase):
                           "be larger than health_check_interval_min of "
                           "%(min_interval)d seconds set in configuration."
                           ) % {"interval": 10, "min_interval": 20}
-        self.assertEqual(expected_error, six.text_type(ex))
+        self.assertEqual(expected_error, str(ex))
 
     @mock.patch.object(health_manager, 'register')
     def test_attach(self, mock_hm_reg):
@@ -217,7 +219,7 @@ class TestHealthPolicy(base.SenlinTestCase):
                     'node_force_recreate': False,
                     'recovery_conditional': 'ANY_FAILED'
                 },
-                'version': '1.1'
+                'version': '1.2'
             }
         }
 
@@ -279,16 +281,33 @@ class TestHealthPolicy(base.SenlinTestCase):
         self.assertEqual("Recovery action REBOOT is only applicable to "
                          "os.nova.server clusters.", data)
 
+    @mock.patch.object(health_manager, 'register')
+    def test_attach_failed_with_notify_timeout(self, mock_hm_reg):
+        mock_hm_reg.return_value = False
+        res, data = self.hp.attach(self.cluster)
+        self.assertFalse(res)
+        self.assertEqual("Registering health manager for cluster timed "
+                         "out.", data)
+
     @mock.patch.object(health_manager, 'unregister')
-    def test_detach(self, mock_hm_reg):
+    def test_detach(self, mock_hm_unreg):
         res, data = self.hp.detach(self.cluster)
         self.assertTrue(res)
         self.assertEqual('', data)
-        mock_hm_reg.assert_called_once_with('CLUSTER_ID')
+        mock_hm_unreg.assert_called_once_with('CLUSTER_ID')
+
+    @mock.patch.object(health_manager, 'unregister')
+    def test_detach_failed_with_notify_timeout(self, mock_hm_unreg):
+        mock_hm_unreg.return_value = False
+        res, data = self.hp.detach(self.cluster)
+        self.assertFalse(res)
+        self.assertEqual("Unregistering health manager for cluster timed "
+                         "out.", data)
+        mock_hm_unreg.assert_called_once_with('CLUSTER_ID')
 
     def test_pre_op_default(self):
         action = mock.Mock(context='action_context', data={},
-                           action=consts.CLUSTER_RECOVER)
+                           action=consts.CLUSTER_SCALE_OUT)
 
         res = self.hp.pre_op(self.cluster.id, action)
 
@@ -311,6 +330,36 @@ class TestHealthPolicy(base.SenlinTestCase):
         self.assertTrue(res)
         mock_disable.assert_called_once_with(self.cluster.id)
 
+    @mock.patch.object(health_manager, 'disable')
+    def test_pre_op_update(self, mock_disable):
+        action = mock.Mock(context='action_context', data={},
+                           action=consts.CLUSTER_UPDATE)
+
+        res = self.hp.pre_op(self.cluster.id, action)
+
+        self.assertTrue(res)
+        mock_disable.assert_called_once_with(self.cluster.id)
+
+    @mock.patch.object(health_manager, 'disable')
+    def test_pre_op_cluster_recover(self, mock_disable):
+        action = mock.Mock(context='action_context', data={},
+                           action=consts.CLUSTER_RECOVER)
+
+        res = self.hp.pre_op(self.cluster.id, action)
+
+        self.assertTrue(res)
+        mock_disable.assert_called_once_with(self.cluster.id)
+
+    @mock.patch.object(health_manager, 'disable')
+    def test_pre_op_cluster_replace_nodes(self, mock_disable):
+        action = mock.Mock(context='action_context', data={},
+                           action=consts.CLUSTER_REPLACE_NODES)
+
+        res = self.hp.pre_op(self.cluster.id, action)
+
+        self.assertTrue(res)
+        mock_disable.assert_called_once_with(self.cluster.id)
+
     @mock.patch.object(health_manager, 'disable')
     def test_pre_op_cluster_del_nodes(self, mock_disable):
         action = mock.Mock(context='action_context', data={},
@@ -395,6 +444,33 @@ class TestHealthPolicy(base.SenlinTestCase):
         self.assertTrue(res)
         mock_enable.assert_called_once_with(self.cluster.id)
 
+    @mock.patch.object(health_manager, 'enable')
+    def test_post_op_update(self, mock_enable):
+        action = mock.Mock(action=consts.CLUSTER_UPDATE)
+
+        res = self.hp.post_op(self.cluster.id, action)
+
+        self.assertTrue(res)
+        mock_enable.assert_called_once_with(self.cluster.id)
+
+    @mock.patch.object(health_manager, 'enable')
+    def test_post_op_cluster_recover(self, mock_enable):
+        action = mock.Mock(action=consts.CLUSTER_RECOVER)
+
+        res = self.hp.post_op(self.cluster.id, action)
+
+        self.assertTrue(res)
+        mock_enable.assert_called_once_with(self.cluster.id)
+
+    @mock.patch.object(health_manager, 'enable')
+    def test_post_op_cluster_replace_nodes(self, mock_enable):
+        action = mock.Mock(action=consts.CLUSTER_REPLACE_NODES)
+
+        res = self.hp.post_op(self.cluster.id, action)
+
+        self.assertTrue(res)
+        mock_enable.assert_called_once_with(self.cluster.id)
+
     @mock.patch.object(health_manager, 'enable')
     def test_post_op_cluster_del_nodes(self, mock_enable):
         action = mock.Mock(action=consts.CLUSTER_DEL_NODES)
