@@ -385,10 +385,13 @@ class TestLoadBalancingPolicy(base.SenlinTestCase):
 
         res, data = policy.attach(cluster)
 
+        cluster_name = cluster.name
+
         self.assertTrue(res)
         self.assertEqual('policy_data', data)
         self.lb_driver.lb_create.assert_called_once_with(policy.vip_spec,
                                                          policy.pool_spec,
+                                                         cluster_name,
                                                          policy.hm_spec,
                                                          policy.az_spec,
                                                          policy.flavor_id_spec)
