@@ -11,9 +11,8 @@
 # under the License.
 
 import collections
+from unittest import mock
 
-import mock
-import six
 
 from senlin.common import constraints
 from senlin.common import exception as exc
@@ -40,7 +39,7 @@ class TestAnyIndexDict(base.SenlinTestCase):
     def test_basic(self):
         sot = schema.AnyIndexDict('*')
 
-        self.assertIsInstance(sot, collections.Mapping)
+        self.assertIsInstance(sot, collections.abc.Mapping)
 
         self.assertEqual('*', sot.value)
         self.assertEqual('*', sot[1])
@@ -79,7 +78,7 @@ class TestSchemaBase(base.SenlinTestCase):
     def test_init_schema_invalid(self):
         ex = self.assertRaises(exc.ESchema, FakeSchema, schema=mock.Mock())
         self.assertEqual('Schema valid only for List or Map, not String',
-                         six.text_type(ex))
+                         str(ex))
 
     def test_get_default(self):
         sot = FakeSchema(default='DEFAULT')
@@ -90,12 +89,12 @@ class TestSchemaBase(base.SenlinTestCase):
         self.assertEqual('VVV', res)
         mock_resolve.assert_called_once_with('DEFAULT')
 
-    def test__validate_default(self):
+    def test_validate_default(self):
         sot = FakeSchema()
 
         self.assertIsNone(sot._validate_default(mock.Mock()))
 
-    def test__validate_default_with_value(self):
+    def test_validate_default_with_value(self):
         sot = FakeSchema(default='DEFAULT')
         mock_validate = self.patchobject(sot, 'validate', return_value=None)
         fake_context = mock.Mock()
@@ -105,7 +104,7 @@ class TestSchemaBase(base.SenlinTestCase):
         self.assertIsNone(res)
         mock_validate.assert_called_once_with('DEFAULT', fake_context)
 
-    def test__validate_default_with_value_but_failed(self):
+    def test_validate_default_with_value_but_failed(self):
         sot = FakeSchema(default='DEFAULT')
         mock_validate = self.patchobject(sot, 'validate',
                                          side_effect=ValueError('boom'))
@@ -116,7 +115,7 @@ class TestSchemaBase(base.SenlinTestCase):
                                fake_context)
 
         mock_validate.assert_called_once_with('DEFAULT', fake_context)
-        self.assertEqual('Invalid default DEFAULT: boom', six.text_type(ex))
+        self.assertEqual('Invalid default DEFAULT: boom', str(ex))
 
     def test_validate_constraints(self):
         c1 = mock.Mock()
@@ -141,9 +140,9 @@ class TestSchemaBase(base.SenlinTestCase):
                                'FOO', context=ctx)
 
         c1.validate.assert_called_once_with('FOO', schema=None, context=ctx)
-        self.assertEqual('BOOM', six.text_type(ex))
+        self.assertEqual('BOOM', str(ex))
 
-    def test__validate_version(self):
+    def test_validate_version(self):
         sot = FakeSchema(min_version='1.0', max_version='2.0')
 
         res = sot._validate_version('field', '1.0')
@@ -161,16 +160,16 @@ class TestSchemaBase(base.SenlinTestCase):
                                'field', '0.9')
         self.assertEqual('field (min_version=1.0) is not supported by '
                          'spec version 0.9.',
-                         six.text_type(ex))
+                         str(ex))
 
         ex = self.assertRaises(exc.ESchema,
                                sot._validate_version,
                                'field', '2.1')
         self.assertEqual('field (max_version=2.0) is not supported by '
                          'spec version 2.1.',
-                         six.text_type(ex))
+                         str(ex))
 
-    def test__validate_version_no_min_version(self):
+    def test_validate_version_no_min_version(self):
         sot = FakeSchema(max_version='2.0')
 
         res = sot._validate_version('field', '1.0')
@@ -184,9 +183,9 @@ class TestSchemaBase(base.SenlinTestCase):
                                'field', '2.1')
         self.assertEqual('field (max_version=2.0) is not supported by '
                          'spec version 2.1.',
-                         six.text_type(ex))
+                         str(ex))
 
-    def test__validate_version_no_max_version(self):
+    def test_validate_version_no_max_version(self):
         sot = FakeSchema(min_version='1.0')
 
         res = sot._validate_version('field', '1.0')
@@ -200,9 +199,9 @@ class TestSchemaBase(base.SenlinTestCase):
                                'field', '0.5')
         self.assertEqual('field (min_version=1.0) is not supported by '
                          'spec version 0.5.',
-                         six.text_type(ex))
+                         str(ex))
 
-    def test__validate_version_no_version_restriction(self):
+    def test_validate_version_no_version_restriction(self):
         sot = FakeSchema()
 
         res = sot._validate_version('field', '1.0')
@@ -317,7 +316,7 @@ class TestBoolean(base.SenlinTestCase):
 
         ex = self.assertRaises(exc.ESchema, sot.to_schema_type, 'bogus')
         self.assertEqual("The value 'bogus' is not a valid Boolean",
-                         six.text_type(ex))
+                         str(ex))
 
     def test_resolve(self):
         sot = schema.Boolean()
@@ -342,7 +341,7 @@ class TestBoolean(base.SenlinTestCase):
 
         ex = self.assertRaises(exc.ESchema, sot.validate, 'bogus')
         self.assertEqual("The value 'bogus' is not a valid Boolean",
-                         six.text_type(ex))
+                         str(ex))
 
 
 class TestInteger(base.SenlinTestCase):
@@ -369,7 +368,7 @@ class TestInteger(base.SenlinTestCase):
 
         ex = self.assertRaises(exc.ESchema, sot.to_schema_type, '456L')
         self.assertEqual("The value '456L' is not a valid Integer",
-                         six.text_type(ex))
+                         str(ex))
 
     def test_resolve(self):
         sot = schema.Integer()
@@ -387,7 +386,7 @@ class TestInteger(base.SenlinTestCase):
 
         ex = self.assertRaises(exc.ESchema, sot.resolve, '456L')
         self.assertEqual("The value '456L' is not a valid Integer",
-                         six.text_type(ex))
+                         str(ex))
 
     def test_validate(self):
         sot = schema.Integer()
@@ -409,7 +408,7 @@ class TestInteger(base.SenlinTestCase):
         mock_constraints.assert_called_once_with(1, schema=sot, context=None)
         ex = self.assertRaises(exc.ESchema, sot.validate, 'bogus')
         self.assertEqual("The value 'bogus' is not a valid Integer",
-                         six.text_type(ex))
+                         str(ex))
 
 
 class TestString(base.SenlinTestCase):
@@ -464,10 +463,6 @@ class TestString(base.SenlinTestCase):
         res = sot.validate(u'unicode')
         self.assertIsNone(res)
 
-        ex = self.assertRaises(exc.ESchema, sot.validate, 1)
-        self.assertEqual("The value '1' is not a valid string.",
-                         six.text_type(ex))
-
         mock_constraints = self.patchobject(sot, 'validate_constraints',
                                             return_value=None)
 
@@ -516,7 +511,7 @@ class TestNumber(base.SenlinTestCase):
 
         ex = self.assertRaises(exc.ESchema, sot.validate, "bogus")
         self.assertEqual("The value 'bogus' is not a valid number.",
-                         six.text_type(ex))
+                         str(ex))
 
         mock_constraints = self.patchobject(sot, 'validate_constraints',
                                             return_value=None)
@@ -535,7 +530,7 @@ class TestList(base.SenlinTestCase):
         self.assertEqual('List', sot['type'])
         self.assertEqual('desc', sot['description'])
 
-    def test__get_children(self):
+    def test_get_children(self):
         sot = schema.List('desc', schema=schema.String())
 
         res = sot._get_children(['v1', 'v2'], [0, 1])
@@ -563,7 +558,7 @@ class TestList(base.SenlinTestCase):
         sot = schema.List(schema=schema.String())
 
         ex = self.assertRaises(exc.ESchema, sot.validate, None)
-        self.assertEqual("'None' is not a List", six.text_type(ex))
+        self.assertEqual("'None' is not a List", str(ex))
 
 
 class TestMap(base.SenlinTestCase):
@@ -574,7 +569,7 @@ class TestMap(base.SenlinTestCase):
         self.assertEqual('Map', sot['type'])
         self.assertEqual('desc', sot['description'])
 
-    def test__get_children(self):
+    def test_get_children(self):
         sot = schema.Map('desc', schema={'foo': schema.String()})
 
         res = sot._get_children({'foo': 'bar'})
@@ -591,7 +586,7 @@ class TestMap(base.SenlinTestCase):
 
         sot = schema.Map(default='bad', schema={'foo': schema.String()})
         ex = self.assertRaises(exc.ESchema, sot.get_default)
-        self.assertEqual("'bad' is not a Map", six.text_type(ex))
+        self.assertEqual("'bad' is not a Map", str(ex))
 
     def test_resolve(self):
         sot = schema.Map(schema={'foo': schema.String()})
@@ -603,7 +598,7 @@ class TestMap(base.SenlinTestCase):
         self.assertEqual({'foo': 'bar'}, res)
 
         ex = self.assertRaises(exc.ESchema, sot.resolve, 'plainstring')
-        self.assertEqual("'plainstring' is not a Map", six.text_type(ex))
+        self.assertEqual("'plainstring' is not a Map", str(ex))
 
     def test_validate(self):
         sot = schema.Map(schema={'foo': schema.String()})
@@ -616,10 +611,10 @@ class TestMap(base.SenlinTestCase):
         sot = schema.Map(schema={'foo': schema.String()})
 
         ex = self.assertRaises(exc.ESchema, sot.validate, None)
-        self.assertEqual("'None' is not a Map", six.text_type(ex))
+        self.assertEqual("'None' is not a Map", str(ex))
 
         ex = self.assertRaises(exc.ESchema, sot.validate, 'bogus')
-        self.assertEqual("'bogus' is not a Map", six.text_type(ex))
+        self.assertEqual("'bogus' is not a Map", str(ex))
 
 
 class TestStringParam(base.SenlinTestCase):
@@ -647,7 +642,7 @@ class TestStringParam(base.SenlinTestCase):
         ex = self.assertRaises(exc.ESchema, sot.validate, '123')
 
         self.assertEqual("'123' must be one of the allowed values: abc, def",
-                         six.text_type(ex))
+                         str(ex))
 
 
 class TestIntegerParam(base.SenlinTestCase):
@@ -675,7 +670,7 @@ class TestIntegerParam(base.SenlinTestCase):
         ex = self.assertRaises(exc.ESchema, sot.validate, 12)
 
         self.assertEqual("'12' must be one of the allowed values: 123, 124",
-                         six.text_type(ex))
+                         str(ex))
 
 
 class TestOperation(base.SenlinTestCase):
@@ -702,7 +697,7 @@ class TestOperation(base.SenlinTestCase):
         ex = self.assertRaises(exc.ESchema, sot.validate,
                                {'baar': 'baar'})
 
-        self.assertEqual("Unrecognizable parameter 'baar'", six.text_type(ex))
+        self.assertEqual("Unrecognizable parameter 'baar'", str(ex))
 
     def test_validate_failed_type(self):
         sot = schema.Operation('des', schema={'foo': schema.StringParam()})
@@ -711,7 +706,7 @@ class TestOperation(base.SenlinTestCase):
                                {'foo': ['baaar']})
 
         self.assertEqual("value is not a string",
-                         six.text_type(ex))
+                         str(ex))
 
     def test_validate_failed_constraint(self):
         sot = schema.Operation(
@@ -726,7 +721,7 @@ class TestOperation(base.SenlinTestCase):
                                {'foo': 'baaar'})
 
         self.assertEqual("'baaar' must be one of the allowed values: bar",
-                         six.text_type(ex))
+                         str(ex))
 
     def test_validate_failed_required(self):
         sot = schema.Operation(
@@ -741,7 +736,7 @@ class TestOperation(base.SenlinTestCase):
                                {'foo': 'baaar'})
 
         self.assertEqual("Required parameter 'bar' not provided",
-                         six.text_type(ex))
+                         str(ex))
 
     def test_validate_failed_version(self):
         sot = schema.Operation(
@@ -755,7 +750,7 @@ class TestOperation(base.SenlinTestCase):
                                {'foo': 'baaar'}, '1.0')
 
         self.assertEqual("foo (min_version=2.0) is not supported by spec "
-                         "version 1.0.", six.text_type(ex))
+                         "version 1.0.", str(ex))
 
 
 class TestSpec(base.SenlinTestCase):
@@ -800,7 +795,7 @@ class TestSpec(base.SenlinTestCase):
         ex = self.assertRaises(exc.ESchema, sot.validate)
 
         self.assertIn("Unrecognizable spec item 'key2'",
-                      six.text_type(ex.message))
+                      str(ex.message))
 
     def test_validate_fail_value_type_incorrect(self):
         spec_schema = {
@@ -812,7 +807,7 @@ class TestSpec(base.SenlinTestCase):
         spec = schema.Spec(spec_schema, data, version='1.0')
         ex = self.assertRaises(exc.ESchema, spec.validate)
         self.assertIn("The value 'abc' is not a valid Integer",
-                      six.text_type(ex.message))
+                      str(ex.message))
 
     def test_validate_version_good(self):
         spec_schema = {
@@ -854,7 +849,7 @@ class TestSpec(base.SenlinTestCase):
         spec = schema.Spec(spec_schema, data, version='1.0')
         ex = self.assertRaises(exc.ESchema, spec.validate)
         msg = 'key1 (min_version=1.1) is not supported by spec version 1.0.'
-        self.assertIn(msg, six.text_type(ex.message))
+        self.assertIn(msg, str(ex.message))
 
     def test_validate_version_fail_version_over_max(self):
         spec_schema = {
@@ -874,7 +869,7 @@ class TestSpec(base.SenlinTestCase):
         spec = schema.Spec(spec_schema, data, version='3.0')
         ex = self.assertRaises(exc.ESchema, spec.validate)
         msg = 'key1 (max_version=2.0) is not supported by spec version 3.0.'
-        self.assertIn(msg, six.text_type(ex.message))
+        self.assertIn(msg, str(ex.message))
 
     def test_resolve_value(self):
         data = {'key2': 2}
@@ -887,7 +882,7 @@ class TestSpec(base.SenlinTestCase):
         self.assertEqual('value1', res)
 
         ex = self.assertRaises(exc.ESchema, sot.resolve_value, 'key3')
-        self.assertEqual("Invalid spec item: key3", six.text_type(ex))
+        self.assertEqual("Invalid spec item: key3", str(ex))
 
     def test_resolve_value_required_key_missing(self):
         data = {'key1': 'value1'}
@@ -895,9 +890,9 @@ class TestSpec(base.SenlinTestCase):
 
         ex = self.assertRaises(exc.ESchema, sot.resolve_value, 'key2')
         self.assertIn("Required spec item 'key2' not provided",
-                      six.text_type(ex.message))
+                      str(ex.message))
 
-    def test___getitem__(self):
+    def test__getitem__(self):
         data = {'key2': 2}
         sot = schema.Spec(self.spec_schema, data, version='1.2')
 
@@ -906,14 +901,14 @@ class TestSpec(base.SenlinTestCase):
         res = sot['key2']
         self.assertEqual(2, res)
 
-    def test___len__(self):
+    def test__len__(self):
         data = {'key2': 2}
         sot = schema.Spec(self.spec_schema, data, version='1.2')
 
         res = len(sot)
         self.assertEqual(2, res)
 
-    def test___contains__(self):
+    def test__contains__(self):
         data = {'key2': 2}
         sot = schema.Spec(self.spec_schema, data, version='1.2')
 
@@ -946,16 +941,16 @@ class TestSpecVersionChecking(base.SenlinTestCase):
         spec = 'a string'
         ex = self.assertRaises(exc.ESchema, schema.get_spec_version, spec)
         self.assertEqual('The provided spec is not a map.',
-                         six.text_type(ex))
+                         str(ex))
 
     def test_spec_version_no_type_key(self):
         spec = {'tpye': 'a string'}
         ex = self.assertRaises(exc.ESchema, schema.get_spec_version, spec)
         self.assertEqual("The 'type' key is missing from the provided "
-                         "spec map.", six.text_type(ex))
+                         "spec map.", str(ex))
 
     def test_spec_version_no_version_key(self):
         spec = {'type': 'a string', 'ver': '123'}
         ex = self.assertRaises(exc.ESchema, schema.get_spec_version, spec)
         self.assertEqual("The 'version' key is missing from the provided "
-                         "spec map.", six.text_type(ex))
+                         "spec map.", str(ex))
